<!--

Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain

-->

<!-- FILENAME:   news.php                              -->
<!-- AUTHOR:     Marcos Martinez Jimenez               -->

<table border="0" width="95%" align="center">
<tr><td class="text6" colspan="4">&nbsp;</td></tr>
<tr><td class="text6" colspan="3"><?php  echo "".$$name_section."";?></td><td class="link1" align="right">

<?php
include ("includes/js/ampliar.js");
include ("includes/languages/".$LANGUAGE."/homesite-news.php");
include ("includes/FCKeditor/fckeditor.php");
if (isset($_COOKIE["id_session"])) {$id_session=$_COOKIE["id_session"];} else {$id_session="NULL";}
if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab=$requested_tab;}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="1";}
if (isset($_GET['task'])){ $task=$_GET['task'];}
if (isset($_POST['choice'])) {$choice=$_POST['choice'];}

// by default, the last 10 infos are showed
if (isset($_GET['first_info'])) {$first_info=$_GET['first_info'];} else {$first_info=0;}

$last_info=$first_info+10;
$last_info_prev=$first_info-10;

include ("includes/db_connect.php");
$info_query=mysql_query("
                        SELECT *
                        FROM info
                        WHERE section='".$name_section."' AND status='2'
                        ORDER BY posted DESC LIMIT $first_info,10
                        ", $db);


$all_infos=mysql_query("SELECT id_info FROM info WHERE section='".$name_section."' AND status='2'", $db);
$num_infos=mysql_num_rows($all_infos);

mysql_data_seek ($album_query, 0);
mysql_data_seek ($info_query, 0);

if ($task!="edit" && $task!="submit" && $task!="delete" && $task!="show_comments" && $task!="put_comment" && $task!="answer_comment" && $task!="anonymous_submit" && $task!="pending" && $choice!=$TEXT025 && $task!="read_more" && $task!="rss_feeds" && $task!="editGUI" && $task!="submitGUI" && $task!="anonymous_submitGUI" && $task!="put_commentGUI" && $task!="answer_commentGUI")
{
if ($id_session[num]==$num && $id_session[num]!="")
   {
    switch ($EDITOR) {
    case "text-html":
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
            "&num=$num&task=submit\">$TEXT001&nbsp;&nbsp;&nbsp;</a>";
       break;
    case "FCKeditor":
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
            "&num=$num&task=submitGUI\">$TEXT001</a>";
       break;
    case "both":
       echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
            "&num=$num&task=submit\">$TEXT001&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
            "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
            "&num=$num&task=submitGUI\">$TEXT001&nbsp;(GUI)</a>";
       break;
    }
   } else {
           switch ($EDITOR) {
           case "text-html":
              echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                   "&num=$num&task=anonymous_submit\">$TEXT001</a>";
           break;
           case "FCKeditor":
              echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                   "&num=$num&task=anonymous_submitGUI\">$TEXT001&nbsp;</a>";
           break;
           case "both":
              echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                   "&num=$num&task=anonymous_submit\">$TEXT001&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
                   "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                   "&num=$num&task=anonymous_submitGUI\">$TEXT001&nbsp;(GUI)</a>";
           }
          }
echo "</td></tr>".
     "<tr><td class=\"text6\" colspan=\"4\"><hr color=\"$TLC\" size=\"$TLS\"></td></tr>".
     "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>";

while ($info_result=mysql_fetch_array ($info_query))
  {
  $body_length=str_word_count($info_result['body_text']);
  $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='".$info_result["id_info"]."'", $db);
  $users_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
  $users_result=mysql_fetch_array($users_query);
  $all_comments=mysql_query("SELECT id_comment FROM comment WHERE id_info='".$info_result["id_info"]."'", $db);
  $num_comments=mysql_num_rows($all_comments);

  echo "<tr><td class=\"title1-black\" colspan=\"4\" bgcolor=\"$HBC\">".$info_result["headline"]."<br>".
       "<span class=\"text1-white\">$TEXT002: ".$info_result["posted"]." $TEXT003 ".$users_result["nick"]."<br>".
       "$TEXT004: ".$info_result["edited"]." $TEXT003 ".$info_result["modified_by"]."</span></td><tr>".
       "<tr><td colspan=\"4\">&nbsp;</td><tr>";

  if (!$info_result)
    {
    echo "<tr><td class=\"alert\"><center>$TEXT005</center></td></tr>";
    } else if ($info_result["attached_photos"]=="NO")
              {
              if ($info_result["use_intro"] == 'YES')
                   {
                   echo "<tr><td class=\"text2\" colspan=\"4\">".$info_result["intro_text"]."</td></tr>";
                   } else echo "<tr><td class=\"text2\" colspan=\"4\">".$info_result["body_text"]."</td></tr>";
              } else if ($info_result["attached_photos"]=="YES")
                        { 
                        if ($info_result["use_intro"] == 'YES')
                           {
                           echo "<tr><td valign=\"top\" class=\"text2\" colspan=\"3\"width=\"70%\">".
                                "".$info_result["intro_text"]."</td>".
                                "<td width=\"30%\" align=\"center\">";
                           } else echo "<tr><td valign=\"top\" class=\"text2\" colspan=\"3\"width=\"70%\">".
                                       "".$info_result["body_text"]."</td>".
                                       "<td width=\"30%\" align=\"center\">";
                        while ($album_result=mysql_fetch_array($album_query))
                              {
                              echo "<img src=\"photos/infos/".$info_result["id_info"]."".
                                   "/thumbnail-".$album_result["filename"]."\" ".
                                   "onClick=\"ampliar('photos/infos/".$info_result["id_info"].
                                   "/".$album_result["filename"]."')\"><br><br>";
                              }
                        echo "</td></tr>";
                        }

  echo "<tr><td class=\"text1\" colspan=\"4\" align=\"right\">";
  if ($info_result["use_intro"] == 'YES')
     {
     echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
          "&num=$num&task=read_more&id_info=".$info_result["id_info"]."\">$TEXT050</a> ($body_length) $TEXT051&nbsp;&nbsp;";
     }

  if ( $num_comments>0 )
     {
     echo "($num_comments)&nbsp;<a href=\"index.php?top_tab=$top_tab".
           "&section_type=$section_type&num=$num&task=show_comments&".
           "id_info=".$info_result["id_info"]."\">$TEXT006</a>&nbsp;";
     } else {
               switch ($EDITOR) {
               case "text-html":
                  echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=put_comment&id_info=".$info_result["id_info"]."\">$TEXT007</a>&nbsp;&nbsp;";
               break;
               case "FCKeditor":
                  echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=put_commentGUI&id_info=".$info_result["id_info"]."\">$TEXT007</a>&nbsp;&nbsp;";
               break;
               case "both":
                  echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=put_comment&id_info=".$info_result["id_info"]."\">$TEXT007&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
                       "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=put_commentGUI&id_info=".$info_result["id_info"]."\">$TEXT007&nbsp;(GUI)</a>&nbsp;&nbsp;";
               break;
               }
            }

  // If the user was login has a athorized user, then the system shows the edit and delete options
  if ($id_session[num]==$num && $id_session[num]!="NULL" && $task!="edit")
     {
     switch ($EDITOR) {
     case "text-html":
        echo "&nbsp<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=edit&id_info=".$info_result["id_info"]."\">$TEXT008</a>&nbsp;&nbsp;";
     break;
     case "FCKeditor":
        echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=editGUI&id_info=".$info_result["id_info"]."\">$TEXT008</a>&nbsp;&nbsp;";
     break;
     case "both":
        echo "&nbsp<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=edit&id_info=".$info_result["id_info"]."\">$TEXT008&nbsp;(HTML-Text)</a>&nbsp;&nbsp;".
             "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=editGUI&id_info=".$info_result["id_info"]."\">$TEXT008&nbsp;(GUI)</a>&nbsp;&nbsp;";
     break;
     }
     echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
          "&num=$num&task=delete&id_info=".$info_result["id_info"]."\">$TEXT009</a>";
     }
  echo "</td></tr>".
       "<tr><td colspan=\"4\">&nbsp;</td></tr>";
  }
echo "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>".
     "<tr><td class=\"text6\" colspan=\"4\"><hr color=\"$BLC\" size=\"$BLS\"></td></tr>";

// if there are more than 10 news, the result is divided into several pages
if ($num_infos > 10)
   { 
   echo "<tr><td colspan=\"4\" align=\"right\">";
   if ($first_info>0)
      {
      echo "<span class=\"text1\"><a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
           "&num=$num&first_info=$last_info_prev\"><<</a> $TEXT010 | </span>";
      }
   if ( $last_info < $num_infos )
      {
      echo "<span class=\"text1\"> $TEXT011 <a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
           "&num=$num&first_info=$last_info\">>></a> ($TEXT012 $num_infos)</span>";
      echo "</td></tr>";
      }
   }


}

// If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
$current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
$current_user=mysql_fetch_array ($current_user_query);

if ($task=="edit" && $current_user["level"] >= "50")
   {
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
   $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
   $info_result=mysql_fetch_array ($info_query);
   $user_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
   $user_result=mysql_fetch_array ($user_query);
   $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='$id_info'", $db);
   $num_photos=mysql_num_rows($album_query);
   echo "<form enctype=\"multipart/form-data\" method=\"post\" action=\"index.php?top_tab=$top_tab".
        "&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n".
        "<input type=\"hidden\" name=\"id_info\" value=\"".$info_result["id_info"]."\">";
   $edited=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT013:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"edited\" value=\"$edited\">".
        "<tr><td class=\"text2\" colspan=4><br><b>$TEXT014</b>: ".$user_result['nick']."</td></tr>".
        "<tr><td class=\"text2b\" colspan=4><br>$TEXT015:</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\" value=\"".$info_result["headline"]."\"></input>".
        "<tr><td class=\"text2b\" colspan=4><br>$TEXT048:</td></tr>";
        if ($info_result['text_type']=="text")
           {
           echo "<tr><td colspan=\"4\">".
                "<textarea name=\"intro_text\" rows=5 cols=72>".strip_tags($info_result["intro_text"]).
                "</textarea></td></tr>".
                "<tr><td class=\"text1\" colspan=4>$TEXT049</td></tr>".
                "<tr><td class=\"text2b\" colspan=4><br>$TEXT016:</td></tr>".
                "<tr><td colspan=\"4\">".
                "<textarea name=\"body_text\" rows=16 cols=72>".strip_tags($info_result["body_text"]).
                "</textarea></td></tr>";
           } else {
                  echo "<tr><td colspan=\"4\">".
                       "<textarea name=\"intro_text\" rows=5 cols=72>".$info_result["intro_text"].
                       "</textarea></td></tr>".
                       "<tr><td class=\"text1\" colspan=4>$TEXT049</td></tr>".
                       "<tr><td class=\"text2b\" colspan=4><br>$TEXT016:</td></tr>".
                       "<tr><td colspan=\"4\">".
                       "<textarea name=\"body_text\" rows=16 cols=72>".$info_result["body_text"].
                       "</textarea></td></tr>";
                  }
        if ($info_result['text_type']=='text'){$select_text="selected=\"selected\"";}
        if ($info_result['text_type']=='html'){$select_html="selected=\"selected\"";}
   echo "<tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"text\" $select_text>$TEXT046</option>".
        "<option value=\"html\" $select_html>$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$TEXT017<br><br></td></tr>";
   if ($num_photos>=1)
      {
      echo "<tr><td class=\"text1\" colspan=4>$TEXT018<br><br></td></tr>".
           "<tr><td class=\"text1b\" align=\"center\" bgcolor=\"$TNED1\">$TEXT019</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=\"$TNED2\">$TEXT020</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=\"$TNED1\">$TEXT021</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=\"$TNED2\">$TEXT022</td></tr>";
      }


   mysql_data_seek ($album_query, 0);
   $n=0;
   while ($album_result=mysql_fetch_array($album_query))
         {
         echo "<tr><td align=\"center\" bgcolor=\"$TNED1\">".
              "<INPUT type=\"checkbox\" name=\"id_photo[$n]\" value=\"".$album_result["id_photo"]."\"></td>".
              "<td class=\"text2\" align=\"center\" bgcolor=\"$TNED2\">".$album_result["filename"]."</td>".
              "<td class=\"text2\" align=\"center\" bgcolor=\"$TNED1\">".$album_result["id_photo"]."</td>".
              "<td bgcolor=\"$TNED2\" align=\"center\">".
              "<img src=\"photos/infos/".$info_result["id_info"]."/thumbnail-".$album_result["filename"]."\">".
              "</td></tr>";
         $n++;
         }

   if ($info_result["status"]==0 )
      {
      echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
           "<tr><td class=\"text2b\" colspan=4><br>Attach Photo:</td></tr>".
           "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
           "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
           "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
           "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT023\"></input><br></td></tr>".
           "</form>";
      }
if ($info_result["status"]==1 || $info_result["status"]==2)
      {
      echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
           "<tr><td class=\"text2b\" colspan=4><br>$TEXT024:</td></tr>".
           "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
           "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
           "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
           "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT026\"></input><br></td></tr>".
           "</form>";
      }

   } else if ($task=="edit") echo "<tr><td colspan=4><span class=\"alert3b\"><center>$TEXT054</center></span></td></tr>";

// If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
$current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
$current_user=mysql_fetch_array ($current_user_query);

if ($task=="editGUI" && $current_user["level"] >= "50")
   {
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
   $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
   $info_result=mysql_fetch_array ($info_query);
   $user_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
   $user_result=mysql_fetch_array ($user_query);
   $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='$id_info'", $db);
   $num_photos=mysql_num_rows($album_query);
   echo "<form enctype=\"multipart/form-data\" method=\"post\" action=\"index.php?top_tab=$top_tab".
        "&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_edit_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n".
        "<input type=\"hidden\" name=\"id_info\" value=\"".$info_result["id_info"]."\">";
   $edited=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT013:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"edited\" value=\"$edited\">".
        "<tr><td class=\"text2\" colspan=4><br><b>$TEXT014</b>: ".$user_result['nick']."</td></tr>".
        "<tr><td class=\"text2b\" colspan=4><br>$TEXT015:</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\" value=\"".$info_result["headline"]."\"></input>".
        "<tr><td class=\"text2b\" colspan=4><br>$TEXT048:</td></tr>";
      echo "<tr><td colspan=\"4\">";
      $oFCKeditor = new FCKeditor('intro_text') ;
      $oFCKeditor->BasePath = 'includes/FCKeditor/';
      $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/my_FCKeditor_config.js';
      $oFCKeditor->ToolbarSet = 'IntroHSMtoolbar';
      $oFCKeditor->Height = '120' ;
         $oFCKeditor->Value = $info_result["intro_text"];
      $oFCKeditor->Create() ;
      echo "</td></tr>".
           "<tr><td class=\"text1\" colspan=4>$TEXT049</td></tr>".
           "<tr><td class=\"text2b\" colspan=4><br>$TEXT016:</td></tr>".
           "<tr><td colspan=\"4\">";
      $oFCKeditor = new FCKeditor('body_text') ;
      $oFCKeditor->BasePath = 'includes/FCKeditor/';
      $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/my_FCKeditor_config.js';
      $oFCKeditor->ToolbarSet = 'BodyHSMtoolbar';
      $oFCKeditor->Height = '350' ;
         $oFCKeditor->Value = $info_result["body_text"];
      $oFCKeditor->Create() ;
      echo "</td></tr>";
   echo "<tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"html\" selected=\"selected\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$TEXT017<br><br></td></tr>";
   if ($num_photos>=1)
      {
      echo "<tr><td class=\"text1\" colspan=4>$TEXT018<br><br></td></tr>".
           "<tr><td class=\"text1b\" align=\"center\" bgcolor=\"$TNED1\">$TEXT019</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=\"$TNED2\">$TEXT020</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=\"$TNED1\">$TEXT021</td>".
           "<td class=\"text1b\" align=\"center\" bgcolor=\"$TNED2\">$TEXT022</td></tr>";
      }


   mysql_data_seek ($album_query, 0);
   $n=0;
   while ($album_result=mysql_fetch_array($album_query))
         {
         echo "<tr><td align=\"center\" bgcolor=\"$TNED1\">".
              "<INPUT type=\"checkbox\" name=\"id_photo[$n]\" value=\"".$album_result["id_photo"]."\"></td>".
              "<td class=\"text2\" align=\"center\" bgcolor=\"$TNED2\">".$album_result["filename"]."</td>".
              "<td class=\"text2\" align=\"center\" bgcolor=\"$TNED1\">".$album_result["id_photo"]."</td>".
              "<td bgcolor=\"$TNED2\" align=\"center\">".
              "<img src=\"photos/infos/".$info_result["id_info"]."/thumbnail-".$album_result["filename"]."\">".
              "</td></tr>";
         $n++;
         }

   if ($info_result["status"]==0 )
      {
      echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
           "<tr><td class=\"text2b\" colspan=4><br>Attach Photo:</td></tr>".
           "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
           "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
           "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
           "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT023\"></input><br></td></tr>".
           "</form>";
      }
if ($info_result["status"]==1 || $info_result["status"]==2)
      {
      echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
           "<tr><td class=\"text2b\" colspan=4><br>$TEXT024:</td></tr>".
           "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
           "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
           "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
           "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT026\"></input><br></td></tr>".
           "</form>";
      }

   } else if ($task=="editGUI") echo "<tr><td colspan=4><span class=\"alert3b\"><center>$TEXT054</center></span></td></tr>";

// If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
if ($id_session[num] == $num && $task=="submit" && $id_session[num] != "")
   {
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n";
   $posted=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=2><br><b>$TEXT027:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"posted\" value=\"$posted\">".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT028:</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\"></input>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT016:</td></tr>".
        "<tr><td colspan=\"4\"><textarea name=\"body_text\" rows=16 cols=72></textarea></td></tr>".
        "<tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"text\">$TEXT046</option>".
        "<option value=\"html\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
        "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
        "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
        "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
        "</form>";
   }

// If the user was loged and selects the edit option (task==editGUI), then he can modify the whole section.
if ($id_session[num] == $num && $task=="submitGUI" && $id_session[num] != "")
   {
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n";
   $posted=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=2><br><b>$TEXT027:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"posted\" value=\"$posted\">".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT028:</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\"></input>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT016:</td></tr>".
        "<tr><td colspan=\"4\">";
        $oFCKeditor = new FCKeditor('body_text') ;
        $oFCKeditor->BasePath = 'includes/FCKeditor/';
        $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/my_FCKeditor_config.js';
        $oFCKeditor->ToolbarSet = 'BodyHSMtoolbar';
        $oFCKeditor->Height = '350' ;
        $oFCKeditor->Value = "$TEXT058";
        $oFCKeditor->Create() ;
   echo "</td></tr>".
        "<tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"html\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
        "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
        "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
        "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
        "</form>";
   }


// If the user in not loged and selects the submit option (task==submit), then he can modify the whole section.
if ($task=="anonymous_submit")
   {
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n";
   $posted=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=2><br><b>$TEXT027:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"posted\" value=\"$posted\">".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT015:</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\"></input>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT016:</td></tr>".
        "<tr><td colspan=\"4\"><textarea name=\"body_text\" rows=16 cols=72></textarea></td></tr>".
        "<tr><td class=\"text1\"  colspan=4>$TEXT045 <sELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"text\">$TEXT046</option>".
        "<option value=\"html\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
        "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
        "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
        "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
        "</form>";
   }

// If the user in not loged and selects the edit option (task==submitGUI), then he can modify the whole section.
if ($task=="anonymous_submitGUI")
   {
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
        "<input type=\"hidden\" name=\"num\" value=\"$num\">".
        "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"2000000\">\n";
   $posted=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=2><br><b>$TEXT027:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"posted\" value=\"$posted\">".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT015:</td></tr>".
        "<tr><td colspan=\"4\"><input type=\"text\" size=50 name=\"headline\"></input>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT016:</td></tr>".
        "<tr><td colspan=\"4\">";
        $oFCKeditor = new FCKeditor('body_text') ;
        $oFCKeditor->BasePath = 'includes/FCKeditor/';
        $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/my_FCKeditor_config.js';
        $oFCKeditor->ToolbarSet = 'BodyHSMtoolbar';
        $oFCKeditor->Height = '350' ;
        $oFCKeditor->Value = "$TEXT058";
        $oFCKeditor->Create() ;
   echo "</td></tr>".
        "<tr><td class=\"text1\"  colspan=4>$TEXT045 <sELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"html\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
        "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
        "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
        "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
        "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
        "</form>";
   }

// If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
if ($id_session[num] == $num && $task=="pending" && $id_session[num] != "")
   {
   $pending_news_query=mysql_query("SELECT id_info, id_author, headline, posted FROM info WHERE status='1'", $db);
   $num_pending_news=mysql_num_rows($pending_news_query);

   $user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session['id_user']."'", $db);
   $user_result=mysql_fetch_array($user_query);

   if ($user_result['level']>=50)
      {
      if ($num_pending_news>0)
         {
         echo "<tr><td class=\"text1\" colspan=5><br>$TEXT029<br><br></td></tr>".
              "<tr><td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$TEXT019</td>".
              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$TEXT030</td>".
              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$TEXT015</td>".
              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$TEXT014</td>".    
              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$TEXT031</td></tr>";
         while ($pending_news=mysql_fetch_array($pending_news_query))
               {
               $user_query=mysql_query("SELECT nick FROM users WHERE id_user='".$pending_news["id_author"]."'", $db);
               $user_result=mysql_fetch_array($user_query);
               echo "<tr><td class=\"text2\"align=\"center\" bgcolor=\"#62acfe\">".
                    "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                    "&num=$num&task=delete&id_info=".$pending_news["id_info"]."\">$TEXT019</td>".
                    "<td class=\"text2\" align=\"center\" bgcolor=\"#62acdd\">".$pending_news["id_info"]."</td>".
                    "<td class=\"text2\" align=\"center\" bgcolor=\"#62acfe\">";
               switch ($EDITOR) {
               case "text-html":
                  echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=edit&id_info=".$pending_news["id_info"]."\">".$pending_news["headline"]."</a></td>";
               break;
               case "FCKeditor":
                  echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=editGUI&id_info=".$pending_news["id_info"]."\">".$pending_news["headline"]."</a></td>";
               break;
               case "both":
                  echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=edit&id_info=".$pending_news["id_info"]."\">".
                       $pending_news["headline"]."&nbsp;(HTML/Text)</a><br>".
                       "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                       "&num=$num&task=editGUI&id_info=".$pending_news["id_info"]."\">".$pending_news["headline"]."&nbsp;(GUI)</a></td>";
               break;
               }
                  echo  "<td class=\"text2\" align=\"center\" bgcolor=\"#62acdd\">".$user_result["nick"]."</td>".
                        "<td class=\"text2\" align=\"center\" bgcolor=\"#62acfe\">".$pending_news["posted"]."</td>".
                        "</td></tr>";
               $n++;
               }
         echo "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
              "</td></tr>";
         } else echo "<tr><td class=\"text1\" colspan=4><br>$TEXT032<br><br></td></tr>";
      } else echo "<tr><td><span class=\"alert3b\"><center>$TEXT044</center></span></td></tr>";
   }

if ($id_session[num] == $num && $task=="delete" && $id_session[num] != "" && $current_user["level"] >= "50")
   {
   // The section is not really deleted, but is updated with default empty info
   // If you wants to delete it completly, then you need to change the config_site.php file
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_delete_info\">".
        "<input type=\"hidden\" name=\"id_info\" value=\"$id_info\">";
   $edited=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   echo "<tr><td class=\"text2\" colspan=2 align=\"center\"><br><b>$TEXT033:</b> $friendly_date</td></tr>".
        "<tr><td class=\"alert3b\" colspan=2\" align=\"center\"><br>$TEXT034</td></tr>".
        "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" value=\"$TEXT019\"></input><br></td></tr>".
        "</form>";
   } else if ($task=="delete") echo "<tr><td colspan=4><span class=\"alert3b\"><center>$TEXT055</center></span></td></tr>";

if ($choice==$TEXT025) // Preview
   {
   include ("includes/db_connect.php");

   $info_query=mysql_query("SELECT * FROM info WHERE id_info='".$id_info."'", $db);
   $info_result=mysql_fetch_array ($info_query);
   $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='".$info_result["id_info"]."'", $db);
   $users_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
   $users_result=mysql_fetch_array($users_query);

   echo "<tr><td class=\"title1-black\" colspan=\"4\" bgcolor=\"$HBC\">".$info_result["headline"]."<br>".
        "<span class=\"text1-white\">$TEXT002: ".$info_result["posted"]." $TEXT003 ".$users_result["nick"]."<br>".
        "$TEXT004: ".$info_result["edited"]." $TEXT003 ".$info_result["modified_by"]."</span></td></tr>".
        "<tr><td colspan=\"4\">&nbsp;</td></tr>";

   if (!$info_result)
      {
      echo "<tr><td class=\"alert\"><center>$TEXT035</center></td></tr>";
      } else if ($info_result["attached_photos"]=="NO")
                {
                if ($info_result["use_intro"] == 'YES')
                   {
                   echo "<tr><td class=\"text2\" colspan=\"4\">".$info_result["intro_text"]."</td></tr>".
                        "<tr><td class=\"text2\" colspan=\"4\">".$info_result["body_text"]."</td></tr>";
                   } else echo "<tr><td class=\"text2\" colspan=\"4\">".$info_result["body_text"]."</td></tr>";
                } else if ($info_result["attached_photos"]=="YES")
                          {
                          if ($info_result["use_intro"] == 'YES')
                             {
                             echo "<tr><td valign=\"top\" class=\"text2\" colspan=\"3\"width=\"70%\">".
                                  "".$info_result["intro_text"]."<br>".$info_result["body_text"]."</td>".
                                  "<td width=\"30%\" align=\"center\">";
                             while ($album_result=mysql_fetch_array($album_query))
                                   {
                                   echo "<img src=\"photos/infos/".$info_result["id_info"]."".
                                        "/thumbnail-".$album_result["filename"]."\" ".
                                        "onClick=\"ampliar('photos/infos/".$info_result["id_info"].
                                        "/".$album_result["filename"]."')\"><br><br>";
                                   }
                             } else {
                                    echo "<tr><td valign=\"top\" class=\"text2\" colspan=\"3\"width=\"70%\">".
                                         "".$info_result["body_text"]."</td>".
                                         "<td width=\"30%\" align=\"center\">";
                                    while ($album_result=mysql_fetch_array($album_query))
                                          {
                                          echo "<img src=\"photos/infos/".$info_result["id_info"]."".
                                               "/thumbnail-".$album_result["filename"]."\" ".
                                               "onClick=\"ampliar('photos/infos/".$info_result["id_info"].
                                               "/".$album_result["filename"]."')\"><br><br>";
                                          }
                                    }
                          echo "</td></tr>";
                          }
echo "<tr><td class=\"link1\" colspan=\"4\" align=\"right\">";
switch ($EDITOR) {
     case "text-html":
        echo "&nbsp<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=edit&id_info=".$info_result["id_info"]."\">$TEXT008</a>&nbsp;&nbsp;";
     break;
     case "FCKeditor":
        echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
              "&num=$num&task=editGUI&id_info=".$info_result["id_info"]."\">$TEXT008</a>&nbsp;&nbsp;";
     break;
     case "both":
        echo "&nbsp<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=edit&id_info=".$info_result["id_info"]."\">$TEXT008&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
             "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=editGUI&id_info=".$info_result["id_info"]."\">$TEXT008&nbsp;(GUI)</a>&nbsp;&nbsp;";
     break;
     }
     echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
          "&num=$num&task=delete&id_info=".$info_result["id_info"]."\">$TEXT009</a>";
echo "</td></tr><tr><td colspan=\"4\">&nbsp;</td></tr>".
     "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>";

    }

if ($task=="read_more")
   {
   include ("includes/db_connect.php");
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
   $info_query=mysql_query("SELECT * FROM info WHERE id_info='".$id_info."'", $db);
   $info_result=mysql_fetch_array ($info_query);
   $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='".$info_result["id_info"]."'", $db);
   $users_query=mysql_query("SELECT nick, level FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
   $users_result=mysql_fetch_array($users_query);
   $all_comments=mysql_query("SELECT id_comment FROM comment WHERE id_info='".$info_result["id_info"]."'", $db);
   $num_comments=mysql_num_rows($all_comments);

   echo "<tr><td class=\"title1-black\" colspan=\"4\" bgcolor=\"$HBC\">".$info_result["headline"]."<br>".
        "<span class=\"text1-white\">$TEXT002: ".$info_result["posted"]." $TEXT003 ".$users_result["nick"]."<br>".
        "$TEXT004: ".$info_result["edited"]." $TEXT003 ".$info_result["modified_by"]."</span></td></tr>".
        "<tr><td colspan=\"4\">&nbsp;</td></tr>";

   if (!$info_result)
      {
      echo "<tr><td class=\"alert\"><center>$TEXT035</center></td></tr>";
      } else if ($info_result["attached_photos"]=="NO")
                {
                if ($info_result["use_intro"] == 'YES')
                   {
                   echo "<tr><td class=\"text2\" colspan=\"4\">".$info_result["intro_text"]."</td></tr>".
                        "<tr><td class=\"text2\" colspan=\"4\">".$info_result["body_text"]."</td></tr>";
                   } else echo "<tr><td class=\"text2\" colspan=\"4\">".$info_result["body_text"]."</td></tr>";
                } else if ($info_result["attached_photos"]=="YES")
                          {
                          if ($info_result["use_intro"] == 'YES')
                             {
                             echo "<tr><td valign=\"top\" class=\"text2\" colspan=\"3\"width=\"70%\">".
                                  "".$info_result["intro_text"]."<br>".$info_result["body_text"]."</td>".
                                  "<td width=\"30%\" align=\"center\">";
                             while ($album_result=mysql_fetch_array($album_query))
                                   {
                                   echo "<img src=\"photos/infos/".$info_result["id_info"]."".
                                        "/thumbnail-".$album_result["filename"]."\" ".
                                        "onClick=\"ampliar('photos/infos/".$info_result["id_info"].
                                        "/".$album_result["filename"]."')\"><br><br>";
                                   }
                             } else {
                                    echo "<tr><td valign=\"top\" class=\"text2\" colspan=\"3\"width=\"70%\">".
                                         "".$info_result["body_text"]."</td>".
                                         "<td width=\"30%\" align=\"center\">";
                                    while ($album_result=mysql_fetch_array($album_query))
                                          {
                                          echo "<img src=\"photos/infos/".$info_result["id_info"]."".
                                               "/thumbnail-".$album_result["filename"]."\" ".
                                               "onClick=\"ampliar('photos/infos/".$info_result["id_info"].
                                               "/".$album_result["filename"]."')\"><br><br>";
                                          }
                                    }
                          echo "</td></tr>";
                          }

echo "<tr><td class=\"link1\" colspan=\"4\" align=\"right\">";
if ( $num_comments>0 )
     {
     echo "&nbsp;<a href=\"index.php?top_tab=$top_tab".
           "&section_type=$section_type&num=$num&task=show_comments&".
           "id_info=".$info_result["id_info"]."\">($num_comments)&nbsp;$TEXT006</a>&nbsp;";
     } else {
            switch ($EDITOR) {
              case "text-html":
                 echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                      "&num=$num&task=put_comment&id_info=".$info_result["id_info"]."\">$TEXT007</a>&nbsp;&nbsp;";
              break;
              case "FCKeditor":
                 echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                      "&num=$num&task=put_commentGUI&id_info=".$info_result["id_info"]."\">$TEXT007</a>&nbsp;&nbsp;";
              break;
              case "both":
                 echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                      "&num=$num&task=put_comment&id_info=".$info_result["id_info"]."\">$TEXT007&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
                      "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                      "&num=$num&task=put_commentGUI&id_info=".$info_result["id_info"]."\">$TEXT007&nbsp;(GUI)</a>&nbsp;&nbsp;";
              break;
              }

            }

     if ($id_session[num]==$num && $id_session[num]!="NULL") // edit and delete will not be showed if you are not a valid user
        {
        switch ($EDITOR) {
        case "text-html":
           echo "&nbsp<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                "&num=$num&task=edit&id_info=".$info_result["id_info"]."\">$TEXT008</a>&nbsp;";
        break;
        case "FCKeditor":
           echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                "&num=$num&task=editGUI&id_info=".$info_result["id_info"]."\">$TEXT008</a>&nbsp";
        break;
        case "both":
           echo "&nbsp<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                "&num=$num&task=edit&id_info=".$info_result["id_info"]."\">$TEXT008&nbsp;(HTML/Text)</a>&nbsp;";
           echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                "&num=$num&task=editGUI&id_info=".$info_result["id_info"]."\">$TEXT008&nbsp;(GUI)</a>&nbsp";
        break;
        }

        echo "&nbsp;<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=delete&id_info=".$info_result["id_info"]."\">$TEXT009</a>".
             "</td></tr><tr><td colspan=\"4\">&nbsp;</td></tr>".
             "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>";
        }

    }

// Every users can see the comments
if ($task=="show_comments") 
   {
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
   $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
   $info_result=mysql_fetch_array ($info_query);
   $users_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
   $users_result=mysql_fetch_array($users_query);
   $all_comments=mysql_query("SELECT * FROM comment WHERE id_info='".$info_result["id_info"]."'", $db);
   $num_comments=mysql_num_rows($all_comments);
   $all_news_comments=mysql_query("SELECT * FROM comment WHERE id_info='".$info_result["id_info"]."' and father_comment='0'", $db);

   echo "<tr><td class=\"text6\" colspan=\"5\"><hr color=\"$TLC\" size=\"$TLS\"></td></tr>".
        "<tr><td class=\"text6\" colspan=\"5\">&nbsp;</td></tr>";

  $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='".$info_result["id_info"]."'", $db);
  echo "<tr><td class=\"title1-black\" colspan=\"5\" bgcolor=\"$HBC\">".$info_result["headline"]."<br>".
       "<span class=\"text1-white\">$TEXT002: ".$info_result["posted"]." $TEXT003 ".$users_result["nick"]."<br>".
       "$TEXT004: ".$info_result["edited"]." $TEXT003 ".$info_result["modified_by"]."</span></td><tr>".
       "<tr><td colspan=\"5\">&nbsp;</td><tr>\n";


  if (!$info_result)
    {
    echo "<tr><td class=\"alert\"><center>$TEXT005</center></td></tr>";
    } else if ($info_result["attached_photos"]=="NO")
              {
              if ($info_result["use_intro"] == 'YES')
                 {
                 echo "<tr><td class=\"text2\" colspan=\"5\">".$info_result["intro_text"]."</td></tr>";
                 } else echo "<tr><td class=\"text2\" colspan=\"5\">".$info_result["body_text"]."</td></tr>";
              } else if ($info_result["attached_photos"]=="YES")
                        {
                        if ($info_result["use_intro"] == 'YES')
                           {
                           echo "<tr><td valign=\"top\" class=\"text2\"".
                                " colspan=\"4\"width=\"70%\">".$info_result["intro_text"]."</td>".
                                "<td width=\"30%\" align=\"center\">";
                           while ($album_result=mysql_fetch_array($album_query))
                                {
                                echo "<img align=\"right\" src=\"photos/infos/".
                                     $info_result["id_info"]."/thumbnail-".$album_result["filename"]."\" ".
                                     "onClick=\"ampliar('photos/infos/".
                                     $info_result["id_info"]."/".
                                     $album_result["filename"]."')\"><br><br>";
                                }
                            } else {
                                   echo "<tr><td valign=\"top\" class=\"text2\"".
                                        " colspan=\"4\"width=\"70%\">".$info_result["body_text"]."</td>".
                                        "<td width=\"30%\" align=\"center\">";
                                   while ($album_result=mysql_fetch_array($album_query))
                                         {
                                         echo "<img align=\"right\" src=\"photos/infos/".
                                              $info_result["id_info"]."/thumbnail-".$album_result["filename"]."\" ".
                                              "onClick=\"ampliar('photos/infos/".
                                              $info_result["id_info"]."/".
                                              $album_result["filename"]."')\"><br><br>";
                                         }
                                   }
                        echo "</td></tr>";
                        }

echo "<tr><td class=\"text1\" colspan=\"5\" align=\"right\">";
if ($info_result["use_intro"] == 'YES')
     {
     $body_length=str_word_count($info_result['body_text']);
     echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
          "&num=$num&task=read_more&id_info=".$info_result["id_info"]."\">$TEXT050</a> ($body_length) $TEXT051&nbsp;&nbsp;";
     }
switch ($EDITOR) {
     case "text-html":
        echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=put_comment&id_info=".$info_result["id_info"]."\">".
             "$TEXT036</a>&nbsp;&nbsp;";
     break;
     case "FCKeditor":
        echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=put_commentGUI&id_info=".$info_result["id_info"]."\">".
             "$TEXT036</a>";
     break;
     case "both":
        echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=put_comment&id_info=".$info_result["id_info"]."\">".
             "$TEXT036&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
             "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
             "&num=$num&task=put_commentGUI&id_info=".$info_result["id_info"]."\">".
             "$TEXT036&nbsp;(GUI)</a>";
     break;
     }

     echo "</td></tr><tr><td class=\"text2\" colspan=\"5\">&nbsp;</td></tr>".
          "<tr><td bgcolor=\"$CBC\" colspan=\"5\" align=\"center\">".
          "<span class=\"title0-black\">$TEXT006 ($num_comments)</span><br>".
          "<span class=\"text2\">$TEXT037</td><tr>".
          "<tr><td colspan=\"5\">&nbsp;</td><tr>";
if ($num_comments>0)
   {
   while ($comments_result=mysql_fetch_array($all_news_comments))
         {
         $users_query2=mysql_query("SELECT nick FROM users WHERE id_user='".$comments_result["id_author"]."'", $db);
         $users_result2=mysql_fetch_array($users_query2);
         if ($comments_result["id_author"]!=0) {$author=$users_result2["nick"];} else {$author="anonymous";}
         echo "<tr><td class=\"text2b\" colspan=\"5\" bgcolor=\"$CTBC\">".$comments_result["title"]."<br>".
              "<span class=\"text1\">$TEXT002: ".$comments_result["posted"]." $TEXT003 $author</span></td><tr>".
              "<tr><td class=\"text2\" colspan=\"5\">".$comments_result["body_text"]."</td></tr>".
              "<tr><td class=\"link1\" colspan=\"5\" align=\"right\">";

         switch ($EDITOR) {
            case "text-html":
               echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                    "&id_comment=".$comments_result["id_comment"]."&num=$num&task=answer_comment".
                    "&id_info=".$info_result["id_info"]."\">$TEXT038</a>&nbsp;&nbsp;";
            break;
            case "FCKeditor":
               echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                    "&id_comment=".$comments_result["id_comment"]."&num=$num&task=answer_commentGUI".
                    "&id_info=".$info_result["id_info"]."\">$TEXT038</a>";
            break;
            case "both":
               echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                    "&id_comment=".$comments_result["id_comment"]."&num=$num&task=answer_comment".
                    "&id_info=".$info_result["id_info"]."\">$TEXT038&nbsp;(HTML/Text)</a>&nbsp;&nbsp;".
                    "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                    "&id_comment=".$comments_result["id_comment"]."&num=$num&task=answer_commentGUI".
                    "&id_info=".$info_result["id_info"]."\">$TEXT038&nbsp;(GUI)</a>";
            break;
            }

         echo "</td></tr>";
         $all_answer_comments=mysql_query("SELECT * 
                                           FROM comment 
                                           WHERE id_info='".$info_result["id_info"]."' 
                                           and father_comment='".$comments_result["id_comment"]."'"
                                           , $db);
         while ($answers_result=mysql_fetch_array($all_answer_comments))
               {
               $users_query3=mysql_query("SELECT nick FROM users WHERE id_user='".$answers_result["id_author"]."'", $db);
               $users_result3=mysql_fetch_array($users_query3);
               if ($answers_result["id_author"]!=0) {$author=$users_result3["nick"];} else {$author="anonymous";}
               echo "<tr><td with=\"100%\"class=\"text2\" colspan=\"6\" bgcolor=\"$RCTBC\">".
                    "$TEXT039: <b>".$answers_result["title"]."</b><br>".
                    "<span class=\"text1\">$TEXT002: ".$answers_result["posted"]." $TEXT003 $author</span></td><tr>".
                    "<tr><td with=\"100%\" class=\"text2\"".
                    " colspan=\"6\">".$answers_result["body_text"]."<br>&nbsp;</td></tr>";
               }
         }
   }

echo "<tr><td class=\"text2\" colspan=\"5\">&nbsp;</td></tr>".
     "<tr><td class=\"text6\" colspan=\"5\"><hr color=\"$BLC\" size=\"$BLS\"></td></tr>";
   }

if ($task=="put_comment" || $task=="answer_comment")
   {
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="ERROR";}
   if (isset($_GET['id_comment'])) {$id_comment=$_GET['id_comment'];} else {$id_comment=0;}
   if ($task=="put_comment")
      {
      $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
      } else if ($task=="answer_comment") {$info_query=mysql_query("SELECT * FROM comment WHERE id_comment='$id_comment'", $db);}
   $info_result=mysql_fetch_array ($info_query);
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_put_comment\">".
        "<input type=\"hidden\" name=\"id_info\" value=\"$id_info\">".
        "<input type=\"hidden\" name=\"id_comment\" value=\"$id_comment\">";
   $posted=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   if ($task=="put_comment")
      {
   echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT040:</b></td></tr>".
        "<tr><td class=\"text3\" colspan=4>".$info_result["headline"]."</b></td></tr>";
      } else if ($task=="answer_comment") 
                {
                echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT041:</b></td></tr>".
                     "<tr><td class=\"text3\" colspan=4>".$info_result["title"]."</b></td></tr>";
                }

   echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT027:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"posted\" value=\"$posted\">".
        "<tr><td class=\"text2b\" colspan=4><br>$TEXT042:</td></tr>";
   if ($task=="put_comment")
      {
      echo "<tr><td colspan=\"2\">".
           "<input type=\"text\" size=50 name=\"title\" value=\"Re: ".$info_result["headline"]."\"></input>";
      } else if ($task=="answer_comment")
                {
                echo "<tr><td colspan=\"2\">".
                     "<input type=\"text\" size=50 name=\"title\" value=\"Re: ".$info_result["title"]."\"></input>";
                }
   echo "<tr><td class=\"text2b\" colspan=4><br>$TEXT043:</td></tr>".
        "<tr><td colspan=\"4\"><textarea name=\"body_text\" rows=16 cols=72></textarea></td></tr>".
        "<tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"text\">$TEXT046</option>".
        "<option value=\"html\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$TEXT017<br><br></td></tr>".
        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT059".
        "<img src=\"includes/create_captcha.php\"></td></tr>".
        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT060".
        "<input type=text name=\"typed_secret_code\" size=4></input></td></tr>".
        "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
        "&nbsp;<input type=\"submit\" value=\"$TEXT001\"></input><br></td></tr>".
        "</form>";

   }

if ($task=="put_commentGUI" || $task=="answer_commentGUI")
   {
   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="ERROR";}
   if (isset($_GET['id_comment'])) {$id_comment=$_GET['id_comment'];} else {$id_comment=0;}
   if ($task=="put_commentGUI")
      {
      $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
      } else if ($task=="answer_commentGUI") {$info_query=mysql_query("SELECT * FROM comment WHERE id_comment='$id_comment'", $db);}
   $info_result=mysql_fetch_array ($info_query);
   echo "<form enctype=\"multipart/form-data\" method=\"post\"".
        " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
        "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_put_comment\">".
        "<input type=\"hidden\" name=\"id_info\" value=\"$id_info\">".
        "<input type=\"hidden\" name=\"id_comment\" value=\"$id_comment\">";
   $posted=date ("Y-m-d H:i:s"); // gets the actual data string
   $friendly_date=date ("l d of Y, H:i:s"); // gets the actual data in frienly mode
   if ($task=="put_comment")
      {
   echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT040:</b></td></tr>".
        "<tr><td class=\"text3\" colspan=4>".$info_result["headline"]."</b></td></tr>";
      } else if ($task=="answer_comment") 
                {
                echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT041:</b></td></tr>".
                     "<tr><td class=\"text3\" colspan=4>".$info_result["title"]."</b></td></tr>";
                }

   echo "<tr><td class=\"text2\" colspan=4><br><b>$TEXT027:</b> $friendly_date</td></tr>".
        "<input type=\"hidden\" name=\"posted\" value=\"$posted\">".
        "<tr><td class=\"text2b\" colspan=4><br>$TEXT042:</td></tr>";
   if ($task=="put_commentGUI")
      {
      echo "<tr><td colspan=\"2\">".
           "<input type=\"text\" size=50 name=\"title\" value=\"Re: ".$info_result["headline"]."\"></input>";
      } else if ($task=="answer_commentGUI")
                {
                echo "<tr><td colspan=\"2\">".
                     "<input type=\"text\" size=50 name=\"title\" value=\"Re: ".$info_result["title"]."\"></input>";
                }
   echo "<tr><td class=\"text2b\" colspan=4><br>$TEXT043:</td></tr>".
        "<tr><td colspan=\"4\">";
   $oFCKeditor = new FCKeditor('body_text') ;
   $oFCKeditor->BasePath = 'includes/FCKeditor/';
   $oFCKeditor->Config['CustomConfigurationsPath'] = '../../js/my_FCKeditor_config.js';
   $oFCKeditor->ToolbarSet = 'CommentHSMtoolbar';
   $oFCKeditor->Height = '200' ;
   $oFCKeditor->Value = "$TEXT057";
   $oFCKeditor->Create() ;

   echo "</td></tr><tr><td class=\"text1\"  colspan=4>$TEXT045 <SELECT name=\"text_type\" class=\"text1\">".
        "<option value=\"html\">$TEXT047</option>".
        "</SELECT></td></tr>".
        "<tr><td class=\"text1\" colspan=4>$TEXT017<br><br></td></tr>".
        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT059".
        "<img src=\"includes/create_captcha.php\"></td></tr>".
        "<tr><td colspan=4 class=\"text2\" align=\"center\">$TEXT060".
        "<input type=text name=\"typed_secret_code\" size=4></input></td></tr>".
        "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
        "&nbsp;<input type=\"submit\" value=\"$TEXT001\"></input><br></td></tr>".
        "</form>";
  }

if ($task=="rss_feeds")
   {
   echo "<tr><td class=\"text6\" colspan=\"4\"><hr color=\"$TLC\" size=\"$TLS\"></td></tr>".
        "<tr><td class=\"title1-black\" colspan=\"4\"><br>$TEXT052<br>".
        "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>".
        "<tr><td class=\"text2\"colspan=\"4\">$TEXT053</td></tr>".
        "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>";
   $news=0;
   for ($tab = 1; $tab <= 4; $tab++ )
       {
       for ($section = 1; $section <= 4; $section++)
           {
           $section_type_str = "SECTION_TYPE_"."$tab"."$section";
           $section_name_str = "TAB_"."$tab"."$section";
           if ($$section_type_str == "news") // Shows the RSS logo only if one news section exists
              {
              echo "<tr><td class=\"link1\" colspan=\"4\">&nbsp;&nbsp;&nbsp;&nbsp;".
                   "<a href=\"rss/news$tab$section.rss\">".
                   "<img src=\"images/logos/rss_icon.png\" border=\"0\" align=\"middle\">&nbsp;&nbsp;".$$section_name_str.
                   "</a>".
                   "</td></tr>";
              }
           }
       }
   echo "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>".
        "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>".
        "<tr><td class=\"text2\" colspan=\"4\" align=\"center\">$TEXT056 </td></tr>".
        "<tr><td class=\"text6\" colspan=\"4\">&nbsp;</td></tr>".
        "<tr><td class=\"link1\" colspan=\"4\" align=\"center\">".
        "<a href=\"http://feedvalidator.org\">".
        "<img src=\"images/logos/valid-rss.png\" border=\"0\" align=\"middle\" alt=\"[Valid RSS]\" title=\"Validate my RSS feeds\" />".
        " http://feedvalidator.org</a></td></tr>".
        "<tr><td class=\"text6\" colspan=\"4\"><hr color=\"$TLC\" size=\"$TLS\"></td></tr>";
   }

?>

</table>
